graph_gsta_goMF<-function(h,...){
	try(({GOtable.outMF_Affy<-GOtable.outMF_Affy;GOtable.outMF_Ag1<-GOtable.outMF_Ag1;GOtable.outMF_Ag2<-GOtable.outMF_Ag2;
		GOtable.outMF_Il_B<-GOtable.outMF_Il_B;GOtable.outMF_Il_L<-GOtable.outMF_Il_L;GOtable.outMF_N<-GOtable.outMF_N;
		GOtable.outMF_S<-GOtable.outMF_S;GOtable.outMF_O<-GOtable.outMF_O;g1_1<-g1_1;l<-l;tree<-tree;
	}),silent=TRUE)
	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("GOtable.outMF_Affy"))aa=length(GOtable.outMF_Affy)
		if(exists("GOtable.outMF_Ag1"))bb=length(GOtable.outMF_Ag1)
		if(exists("GOtable.outMF_Ag2"))cc=length(GOtable.outMF_Ag2)
		if(exists("GOtable.outMF_Il_B"))dd=length(GOtable.outMF_Il_B)
		if(exists("GOtable.outMF_Il_L"))ee=length(GOtable.outMF_Il_L)
		if(exists("GOtable.outMF_N"))ff=length(GOtable.outMF_N)
		if(exists("GOtable.outMF_S"))gg=length(GOtable.outMF_S)
		if(exists("GOtable.outMF_O"))hh=length(GOtable.outMF_O)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")

	graph_gsta_goMF_Affy=NULL;graph_gsta_goMF_Ag1=NULL;graph_gsta_goMF_Ag2=NULL;graph_gsta_goMF_Il_B=NULL;graph_gsta_goMF_Il_L=NULL;
	graph_gsta_goMF_N=NULL;graph_gsta_goMF_S=NULL;graph_gsta_goMF_O=NULL;
	legend_gsta_goMF_Affy=NULL;legend_gsta_goMF_Ag1=NULL;legend_gsta_goMF_Ag2=NULL;legend_gsta_goMF_Il_B=NULL;legend_gsta_goMF_Il_L=NULL;
	legend_gsta_goMF_N=NULL;legend_gsta_goMF_S=NULL;legend_gsta_goMF_O=NULL;p_v_1=NULL;p_v_2=NULL;view_ww=NULL;
	nodefill_gsta_goMF_Affy=NULL;g_gsta_goMF_Affy=NULL;nodefill_gsta_goMF_Ag1=NULL;g_gsta_goMF_Ag1=NULL;
	nodefill_gsta_goMF_Ag2=NULL;g_gsta_goMF_Ag2=NULL;nodefill_gsta_goMF_Il_B=NULL;g_gsta_goMF_Il_B=NULL;
	nodefill_gsta_goMF_Il_L=NULL;g_gsta_goMF_Il_L=NULL;nodefill_gsta_goMF_N=NULL;g_gsta_goMF_N=NULL;
	nodefill_gsta_goMF_S=NULL;g_gsta_goMF_S=NULL;nodefill_gsta_goMF_O=NULL;g_gsta_goMF_O=NULL;

	rm(graph_gsta_goMF_Affy,graph_gsta_goMF_Ag1,graph_gsta_goMF_Ag2,graph_gsta_goMF_Il_B,graph_gsta_goMF_Il_L,
	graph_gsta_goMF_N,graph_gsta_goMF_S,graph_gsta_goMF_O,
	nodefill_gsta_goMF_Affy,g_gsta_goMF_Affy,nodefill_gsta_goMF_Ag1,g_gsta_goMF_Ag1,
	nodefill_gsta_goMF_Ag2,g_gsta_goMF_Ag2,nodefill_gsta_goMF_Il_B,g_gsta_goMF_Il_B,
	nodefill_gsta_goMF_Il_L,g_gsta_goMF_Il_L,nodefill_gsta_goMF_N,g_gsta_goMF_N,
	nodefill_gsta_goMF_S,g_gsta_goMF_S,nodefill_gsta_goMF_O,g_gsta_goMF_O,
	legend_gsta_goMF_Affy,legend_gsta_goMF_Ag1,legend_gsta_goMF_Ag2,legend_gsta_goMF_Il_B,legend_gsta_goMF_Il_L,
	legend_gsta_goMF_N,legend_gsta_goMF_S,legend_gsta_goMF_O,p_v_1,p_v_2,view_ww)

	x=NULL
	f<-function(h,...){
		x<<-svalue(h$obj)
		}
	z=NULL
	w_gsea<-gwindow("Select p-value",fill="y",height=100,width=100)
	gp_gsea<-ggroup(container=w_gsea)
	gp_gsea_1<-ggroup(container=gp_gsea,fill="y")
	glabel("Lower limit",container=gp_gsea_1)
	ge_gsea_1<-gedit("",initial.msg="0",width=10,height=20,container=gp_gsea_1,anchor=c(-1,1))

	gp_gsea_2<-ggroup(container=gp_gsea,fill="y")
	glabel("Upper limit",container=gp_gsea_2)
	ge_gsea_2<-gedit("",initial.msg="0.05",width=10,height=20,container=gp_gsea_2,anchor=c(-1,1))

	gp_gsea2<-ggroup(container=w_gsea)
	gbutton("CANCEL",border=TRUE,handler=function(h,...){
		p_v_1<<-svalue(ge_gsea_1)
		p_v_2<<-svalue(ge_gsea_2)
		svalue(sb)<-"Done"
		dispose(w_gsea)
	},container=gp_gsea2,anchor=c(1,-1))
	gbutton("OK",border=TRUE,handler=function(h,...){
		p_v_1<<-svalue(ge_gsea_1)
		if(p_v_1=="")p_v_1<<-0;
		p_v_2<<-svalue(ge_gsea_2)
		if(p_v_2=="")p_v_2<<-0.05;
		p_v_1<<-as.numeric(p_v_1);p_v_2<<-as.numeric(p_v_2);
		dispose(w_gsea)
		svalue(sb)<-"				Please wait while Graphs.."
		w_dge<-gwindow("Select your data",width=260,height=280,visible=FALSE,fill="y")
		gp_dge<-ggroup(container=w_dge,fill="y")
		cbg_dge<-gcheckboxgroup(platforms,container=gp_dge,handler=f)
		svalue(cbg_dge,index=FALSE)<-1:8
		gp2_dge<-ggroup(container=gp_dge,width=30,height=15,fill="x")
		addSpring(gp2_dge)
		y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
			dispose(w_dge)
		},container=gp2_dge,anchor=c(1,-1))
		y2<-gbutton("OK",border=TRUE,handler=function(h,...){
			if(length(x)!=0){
				dispose(w_dge)
				if(length(which(x=="Affymetrix"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_Affy)[GOtable.outMF_Affy$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_Affy)[GOtable.outMF_Affy$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_Affy<<-nodefill
					g_gsta_goMF_Affy<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_Affy<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_Affy<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_Affy)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_Affy,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_Affy)!=0){
						visible(g1_1)<-FALSE
						l$Affymetrix$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Agilent_OneColor"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_Ag1)[GOtable.outMF_Ag1$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_Ag1)[GOtable.outMF_Ag1$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_Ag1<<-nodefill
					g_gsta_goMF_Ag1<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_Ag1<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_Ag1<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_Ag1)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_Ag1,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_Ag1)!=0){
						visible(g1_1)<-FALSE
						l$Agilent_OneColor$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Agilent_TwoColor"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_Ag2)[GOtable.outMF_Ag2$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_Ag2)[GOtable.outMF_Ag2$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_Ag2<<-nodefill
					g_gsta_goMF_Ag2<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_Ag2<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_Ag2<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_Ag2)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_Ag2,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_Ag2)!=0){
						visible(g1_1)<-FALSE
						l$Agilent_TwoColor$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Illumina_Beadarray"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_Il_B)[GOtable.outMF_Il_B$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_Il_B)[GOtable.outMF_Il_B$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_Il_B<<-nodefill
					g_gsta_goMF_Il_B<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_Il_B<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_Il_B<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_Il_B)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_Il_B,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_Il_B)!=0){
						visible(g1_1)<-FALSE
						l$Illumina_Beadarray$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Illumina_Lumi"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_Il_L)[GOtable.outMF_Il_L$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_Il_L)[GOtable.outMF_Il_L$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_Il_L<<-nodefill
					g_gsta_goMF_Il_L<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_Il_L<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_Il_L<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_Il_L)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_Il_L,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_Il_L)!=0){
						visible(g1_1)<-FALSE
						l$Illumina_Lumi$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Nimblegen"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_N)[GOtable.outMF_N$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_N)[GOtable.outMF_N$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_N<<-nodefill
					g_gsta_goMF_N<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_N<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_N<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_N)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_N,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_N)!=0){
						visible(g1_1)<-FALSE
						l$Nimblegen$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Series_Matrix"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_S)[GOtable.outMF_S$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_S)[GOtable.outMF_S$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_S<<-nodefill
					g_gsta_goMF_S<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_S<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_S<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_S)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_S,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_S)!=0){
						visible(g1_1)<-FALSE
						l$Series_Matrix$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				if(length(which(x=="Online_Data"))!=0)
				{
					try(dispose(view_ww),silent=TRUE)
					p1<-rownames(GOtable.outMF_O)[GOtable.outMF_O$"p-value">=p_v_1]
					p2<-rownames(GOtable.outMF_O)[GOtable.outMF_O$"p-value"<=p_v_2]
					p<-p2[match(p1,p2)]
					GO.vec<-p[!is.na(p)==TRUE]
					g<-GOGraph(GO.vec,GOMFPARENTS)
					g<-removeNode("all",g)
					nodes<-buildNodeList(g)
					focusnode<-sapply(nodes,name) %in% GO.vec
					names(focusnode)<-names(nodes)
					nodefill<-ifelse(focusnode,"yellow","white")
					nodefill_gsta_goMF_O<<-nodefill
					g_gsta_goMF_O<<-g
					nAttrs<-list()
					nAttrs$fillcolor<-nodefill
					graph_gsta_goMF_O<<-plot(g,nodeAttrs=nAttrs)
					terms<-getGOTerm(nodes(g))
					legend<-data.frame(terms)
					legend_gsta_goMF_O<<-data.frame(rownames(legend),legend)
					colnames(legend_gsta_goMF_O)<<-c("Identifier","MF")
					view_ww<<-gwindow("Graph_Legend",visible=FALSE,height=400,width=600)
					gtable(legend_gsta_goMF_O,container=view_ww)
					visible(view_ww)<<-TRUE
					if(length(graph_gsta_goMF_O)!=0){
						visible(g1_1)<-FALSE
						l$Online_Data$Graph_GSTA_GO$MF<<-list()
						tr<<-gtree(offspring=tree,container=g1_1)
						size(tr)<-c(300,400)
						visible(g1_1)<-TRUE
					}
					display()	
				}
				svalue(sb)<-"Done"
				dispose(w_dge)
				}else{
				gmessage("Plz select the data for generating Co-expression network","Select Data")
			}
		},container=gp2_dge,anchor=c(1,-1)
		)
		visible(w_dge)<-TRUE
	},container=gp_gsea2,anchor=c(1,-1)
	)
}
